@@ -4,33 +4,35 @@
 #include <wx/wx.h>
 #include <wx/treebase.h>
 
+#include "config.h"
+
 #define MAX_WIKI_TEXT_SIZE 10000
 #define MAX_BUF_SIZE       1024
 #define EXT_TAG             ".txt"
 #define DATE_TAG            ":''DATE'':"
-#define NEW_DATA            DATE_TAG " %Y/%m/%d %H:%M:%S\n\n:''TYPE'': memo\n----\n"
+#define NEW_DATA            DATE_TAG " %Y/%m/%d %H:%M:%S\n\n:''TYPE'': memo\n---------------------------------------------------------\n"
 
-#define CODE_SET_EUC_JP	    "eucJP"
+#define CODE_SET_EUC_JP	    "euc-jp"
 #ifdef __WXMAC__
-	#define CODE_SET_SYSTEM "SJIS"
+	#define CODE_SET_SYSTEM "CP932"
 #endif
 #ifdef __WXCOCOA__
-	#define CODE_SET_SYSTEM "SJIS"
+	#define CODE_SET_SYSTEM "CP932"
 #endif
 #ifdef __WXMSW__
-	#define CODE_SET_SYSTEM "SJIS"
+	#define CODE_SET_SYSTEM "CP932"
 #endif
 #ifdef __WXMOTIF__
 	#define CODE_SET_SYSTEM "eucJP"
 #endif
 #ifdef __WXGTK__
-	#define CODE_SET_SYSTEM "eucJP"
+	#define CODE_SET_SYSTEM "euc-jp"
 #endif
 #ifdef __WXX11__
 	#define CODE_SET_SYSTEM "eucJP"
 #endif
 
-
+#define MAC_BACKSLASH 0x80
 
 
 class WikiData : wxTreeItemData{
@@ -72,6 +74,7 @@ public:
 	void modSearchStr(wxString* oldStr, wxString* newStr);
 	const wxArrayString* getSearchStrList();
 	WikiData* newWikiData();
+	const wxString* getWikiDataDir();
 
 private:
     wxString*      wikiDataDir;
